@@ -123,6 +123,14 @@ class InputData:
             )
 
     def validate_molecule_info(self, molecule_info):
+        if not isinstance(
+            molecule_info["symbols"], list
+        ):
+            raise Exception("Symmbols must be a list of nuclei.")
+        if not isinstance(
+            molecule_info["coords"], list
+        ):
+            raise Exception("Coords must be a list of tuples representing the x, y, z position of each nuclei.")
         if "mutiplicity" in molecule_info and not isinstance(
             molecule_info["mutiplicity"], int
         ):
@@ -631,13 +639,18 @@ In case the service has been recently started please wait 5 minutes for it to be
 
     def _store_state(self):
         state = str(uuid.uuid4())
-        session = requests.Session()
-        session_response = session.get(
+        #session = requests.Session()
+        # session_response = session.put(
+        #     f"{self._asp_net_url}/auth/storestate",
+        #     params={"state": state},
+        #     verify=self._use_https,
+        # )
+        response = requests.post(
             f"{self._asp_net_url}/auth/storestate",
-            params={"state": state},
+            json={"state": state},
             verify=self._use_https,
         )
-        if session_response.status_code != 200:
+        if response.status_code != 200:
             if not self._is_server_online(self._asp_net_url):
                 raise AuthenticationFailure(
                     f"The service you are trying to access at: {self._asp_net_url} is not online."
